@@ -387,8 +387,6 @@ class UbuntuSSOClientGUI(object):
                 msg = 'UbuntuSSOClientGUI: failed set_transient_for win id %r'
                 logger.exception(msg, window_id)
 
-        # Hidding unused widgets to save some space (LP #627440).
-        self.name_entry.hide()
         self.yes_to_updates_checkbutton.hide()
 
         self.window.show()
@@ -769,11 +767,10 @@ class UbuntuSSOClientGUI(object):
 
         error = False
 
-        # Hidding unused widgets to save some space (LP #627440).
-        #name = self.name_entry.get_text()
-        #if not name:
-        #    self.name_entry.set_warning(self.FIELD_REQUIRED)
-        #    error = True
+        name = self.name_entry.get_text()
+        if not name:
+            self.name_entry.set_warning(self.FIELD_REQUIRED)
+            error = True
 
         # check email
         email1 = self.email1_entry.get_text()
@@ -811,11 +808,12 @@ class UbuntuSSOClientGUI(object):
         self.user_email = email1
         self.user_password = password1
 
-        logger.info('Calling register_user with email %r, password <hidden>,' \
-                    ' captcha_id %r and captcha_solution %r.', email1,
-                    self._captcha_id, captcha_solution)
-        f = self.backend.register_user
-        f(self.app_name, email1, password1, self._captcha_id, captcha_solution,
+        logger.info('Calling register_with_name with email %r, password, '
+                    '<hidden> name %r, captcha_id %r and captcha_solution %r.',
+                    email1, name, self._captcha_id, captcha_solution)
+        f = self.backend.register_with_name
+        f(self.app_name, email1, password1, name,
+          self._captcha_id, captcha_solution,
           reply_handler=NO_OP, error_handler=NO_OP)
 
     def on_tc_button_clicked(self, *args, **kwargs):
