@@ -171,24 +171,27 @@ class SSOLoginProcessor(object):
 
         return captcha['captcha_id']
 
-    def register_user(self, email, password, captcha_id, captcha_solution):
+    def register_with_name(self, email, password, displayname,
+                      captcha_id, captcha_solution):
         """Register a new user with 'email' and 'password'."""
-        logger.debug('register_user: email: %r password: <hidden>, '
-                     'captcha_id: %r, captcha_solution: %r',
-                     email, captcha_id, captcha_solution)
+        logger.debug('register_with_name: email: %r password: <hidden>, '
+                     'displayname: %r, captcha_id: %r, captcha_solution: %r',
+                     email, displayname, captcha_id, captcha_solution)
         sso_service = self.sso_service_class(None, self.service_url)
         if not self._valid_email(email):
-            logger.error('register_user: InvalidEmailError for email: %r',
+            logger.error('register_with_name: InvalidEmailError for email: %r',
                          email)
             raise InvalidEmailError()
         if not self._valid_password(password):
-            logger.error('register_user: InvalidPasswordError')
+            logger.error('register_with_name: InvalidPasswordError')
             raise InvalidPasswordError()
 
         result = sso_service.registrations.register(
-                    email=email, password=password, captcha_id=captcha_id,
+                    email=email, password=password,
+                    displayname=displayname,
+                    captcha_id=captcha_id,
                     captcha_solution=captcha_solution)
-        logger.info('register_user: email: %r result: %r', email, result)
+        logger.info('register_with_name: email: %r result: %r', email, result)
 
         if result['status'] == 'error':
             errorsdict = self._format_webservice_errors(result['errors'])
@@ -198,6 +201,17 @@ class SSOLoginProcessor(object):
         else:
             return email
 
+    def register_user(self, email, password,
+                      captcha_id, captcha_solution):
+        """Register a new user with 'email' and 'password'."""
+        logger.debug('register_user: email: %r password: <hidden>, '
+                     'captcha_id: %r, captcha_solution: %r',
+                     email, captcha_id, captcha_solution)
+        res = self.register_with_name(email, password, displayname='',
+                                      captcha_id=captcha_id,
+                                      captcha_solution=captcha_solution)
+        return res
+
     def login(self, email, password, token_name):
         """Login a user with 'email' and 'password'."""
         logger.debug('login: email: %r password: <hidden>, token_name: %r',
@@ -387,6 +401,17 @@ class SSOLogin(dbus.service.Object):
                                                 captcha_id, captcha_solution)
         blocking(f, app_name, self.UserRegistered, self.UserRegistrationError)
 
+    @dbus.service.method(dbus_interface=DBUS_IFACE_USER_NAME,
+                         in_signature='ssssss')
+    def register_with_name(self, app_name, email, password, name,
+                           captcha_id, captcha_solution):
+        """Call the matching method in the processor."""
+        def f():
+            """Inner function that will be run in a thread."""
+            return self.processor.register_with_name(email, password, name,
+                                                captcha_id, captcha_solution)
+        blocking(f, app_name, self.UserRegistered, self.UserRegistrationError)
+
     # login signals
     @dbus.service.signal(DBUS_IFACE_USER_NAME, signature="ss")
     def LoggedIn(self, app_name, result):
