@@ -63,7 +63,7 @@ class FakedSSOBackend(object):
         self._args = args
         self._kwargs = kwargs
         self._called = {}
-        for i in ('generate_captcha', 'login', 'register_user',
+        for i in ('generate_captcha', 'login', 'register_with_name',
                   'validate_email', 'request_password_reset_token',
                   'set_new_password'):
             setattr(self, i, self._record_call(i))
@@ -674,11 +674,11 @@ class EnterDetailsTestCase(UbuntuSSOClientTestCase):
         """Clicking 'join_ok_button' sends info to backend using 'register'."""
         self.click_join_with_valid_data()
 
-        # assert register_user was called
-        expected = 'register_user'
+        # assert register_with_name was called
+        expected = 'register_with_name'
         self.assertIn(expected, self.ui.backend._called)
         self.assertEqual(self.ui.backend._called[expected],
-                         ((APP_NAME, EMAIL, PASSWORD, CAPTCHA_ID,
+                         ((APP_NAME, EMAIL, PASSWORD, NAME, CAPTCHA_ID,
                            CAPTCHA_SOLUTION),
                           dict(reply_handler=gui.NO_OP,
                                error_handler=gui.NO_OP)))
@@ -1161,12 +1161,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
 
         self.assert_correct_entry_warning(self.ui.name_entry,
                                           self.ui.FIELD_REQUIRED)
-        self.assertNotIn('register_user', self.ui.backend._called)
-
-    # Unused variable 'skip'
-    # pylint: disable=W0612
-    test_warning_is_shown_if_name_empty.skip = \
-        'Unused for now, will be hidden to save space (LP: #627440).'
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_empty_email(self):
         """A warning message is shown if emails are empty."""
@@ -1179,7 +1174,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                                           self.ui.FIELD_REQUIRED)
         self.assert_correct_entry_warning(self.ui.email2_entry,
                                           self.ui.FIELD_REQUIRED)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_email_mismatch(self):
         """A warning message is shown if emails doesn't match."""
@@ -1192,7 +1187,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                                           self.ui.EMAIL_MISMATCH)
         self.assert_correct_entry_warning(self.ui.email2_entry,
                                           self.ui.EMAIL_MISMATCH)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_invalid_email(self):
         """A warning message is shown if email is invalid."""
@@ -1205,7 +1200,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                                           self.ui.EMAIL_INVALID)
         self.assert_correct_entry_warning(self.ui.email2_entry,
                                           self.ui.EMAIL_INVALID)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_password_help_is_always_shown(self):
         """Password help text is correctly displayed."""
@@ -1213,7 +1208,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                         'password help text is visible.')
         self.assertEqual(self.ui.password_help_label.get_text(),
                          self.ui.PASSWORD_HELP)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_password_mismatch(self):
         """A warning message is shown if password doesn't match."""
@@ -1226,7 +1221,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                                           self.ui.PASSWORD_MISMATCH)
         self.assert_correct_entry_warning(self.ui.password2_entry,
                                           self.ui.PASSWORD_MISMATCH)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_password_too_weak(self):
         """A warning message is shown if password is too weak."""
@@ -1241,7 +1236,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
                                               self.ui.PASSWORD_TOO_WEAK)
             self.assert_correct_entry_warning(self.ui.password2_entry,
                                               self.ui.PASSWORD_TOO_WEAK)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_tc_not_accepted(self):
         """A warning message is shown if TC are not accepted."""
@@ -1252,7 +1247,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
 
         self.assert_correct_label_warning(self.ui.tc_warning_label,
                                           self.ui.TC_NOT_ACCEPTED)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_warning_is_shown_if_not_captcha_solution(self):
         """A warning message is shown if TC are not accepted."""
@@ -1263,7 +1258,7 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
 
         self.assert_correct_entry_warning(self.ui.captcha_solution_entry,
                                           self.ui.FIELD_REQUIRED)
-        self.assertNotIn('register_user', self.ui.backend._called)
+        self.assertNotIn('register_with_name', self.ui.backend._called)
 
     def test_no_warning_messages_if_valid_data(self):
         """No warning messages are shown if the data is valid."""
