@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # test_main - tests for ubuntu_sso.main
 #
 # Author: Natalia Bidart <natalia.bidart@canonical.com>
@@ -63,6 +65,7 @@ EMAIL = 'test@example.com'
 EMAIL_ALREADY_REGISTERED = 'a@example.com'
 EMAIL_TOKEN = 'B2Pgtf'
 HELP = 'help text'
+NAME = 'Juanito Pérez'
 PASSWORD = 'be4tiFul'
 RESET_PASSWORD_TOKEN = '8G5Wtq'
 TOKEN = {u'consumer_key': u'xQ7xDAz',
@@ -107,7 +110,8 @@ class FakedCaptchas(object):
 class FakedRegistrations(object):
     """Fake the registrations service."""
 
-    def register(self, email, password, captcha_id, captcha_solution):
+    def register(self, email, password, displayname,
+                 captcha_id, captcha_solution):
         """Fake registration. Return a fix result."""
         if email == EMAIL_ALREADY_REGISTERED:
             return {'status': 'error',
@@ -399,6 +403,16 @@ class SSOLoginProcessorTestCase(TestCase, MockerTestCase):
         self.assertIn('Received invalid reply: %s' % STATUS_UNKNOWN, exc)
 
 
+class SSORegistrationWithNameTestCase(SSOLoginProcessorTestCase):
+    """Test suite for the SSO login processor for register_with_name."""
+
+    def setUp(self):
+        """Init."""
+        super(SSORegistrationWithNameTestCase, self).setUp()
+        self.register_kwargs['displayname'] = NAME
+        self.processor.register_user = self.processor.register_with_name
+
+
 class BlockingSampleException(Exception):
     """The exception that will be thrown by the fake blocking."""
 
@@ -510,8 +524,8 @@ class SsoDbusTestCase(TestCase):
         """Test that the register_user method works ok."""
         d = Deferred()
         expected_result = "expected result"
-        self.create_mock_processor().register_user(EMAIL, PASSWORD, CAPTCHA_ID,
-                                                   CAPTCHA_SOLUTION)
+        self.create_mock_processor().register_user(EMAIL, PASSWORD,
+            CAPTCHA_ID, CAPTCHA_SOLUTION)
         self.mocker.result(expected_result)
         self.patch(ubuntu_sso.main, "blocking", self.fake_ok_blocking)
         self.mocker.replay()
@@ -534,8 +548,8 @@ class SsoDbusTestCase(TestCase):
         """Test that the register_user method fails as expected."""
         d = Deferred()
         expected_result = "expected result"
-        self.create_mock_processor().register_user(EMAIL, PASSWORD, CAPTCHA_ID,
-                                                   CAPTCHA_SOLUTION)
+        self.create_mock_processor().register_user(EMAIL, PASSWORD,
+            CAPTCHA_ID, CAPTCHA_SOLUTION)
         self.mocker.result(expected_result)
         self.patch(ubuntu_sso.main, "blocking", self.fake_err_blocking)
         self.mocker.replay()
@@ -554,6 +568,54 @@ class SsoDbusTestCase(TestCase):
                              CAPTCHA_SOLUTION)
         return d
 
+    def test_register_with_name(self):
+        """Test that the register_with_name method works ok."""
+        d = Deferred()
+        expected_result = "expected result"
+        self.create_mock_processor().register_with_name(EMAIL, PASSWORD, NAME,
+            CAPTCHA_ID, CAPTCHA_SOLUTION)
+        self.mocker.result(expected_result)
+        self.patch(ubuntu_sso.main, "blocking", self.fake_ok_blocking)
+        self.mocker.replay()
+
+        def verify(app_name, result):
+            """The actual test."""
+            self.assertEqual(result, expected_result)
+            self.assertEqual(app_name, APP_NAME)
+            d.callback(result)
+
+        client = SSOLogin(self.mockbusname,
+                          sso_login_processor_class=self.mockprocessorclass)
+        self.patch(client, "UserRegistered", verify)
+        self.patch(client, "UserRegistrationError", d.errback)
+        client.register_with_name(APP_NAME, EMAIL, PASSWORD, NAME, CAPTCHA_ID,
+                             CAPTCHA_SOLUTION)
+        return d
+
+    def test_register_with_name_error(self):
+        """Test that the register_with_name method fails as expected."""
+        d = Deferred()
+        expected_result = "expected result"
+        self.create_mock_processor().register_with_name(EMAIL, PASSWORD, NAME,
+            CAPTCHA_ID, CAPTCHA_SOLUTION)
+        self.mocker.result(expected_result)
+        self.patch(ubuntu_sso.main, "blocking", self.fake_err_blocking)
+        self.mocker.replay()
+
+        def verify(app_name, errdict):
+            """The actual test."""
+            self.assertEqual(errdict["errtype"], "BlockingSampleException")
+            self.assertEqual(app_name, APP_NAME)
+            d.callback("Ok")
+
+        client = SSOLogin(self.mockbusname,
+                          sso_login_processor_class=self.mockprocessorclass)
+        self.patch(client, "UserRegistered", d.errback)
+        self.patch(client, "UserRegistrationError", verify)
+        client.register_with_name(APP_NAME, EMAIL, PASSWORD, NAME, CAPTCHA_ID,
+                             CAPTCHA_SOLUTION)
+        return d
+
     def test_login(self):
         """Test that the login method works ok."""
         d = Deferred()
